@@ -3,23 +3,34 @@
   >>> from five.megrok.layout.ftests.layout.layout import *
   >>> from zope.component import getMultiAdapter
   >>> from zope.publisher.browser import TestRequest
+  >>> from zope.interface.verify import verifyObject
 
   >>> request = TestRequest()
-  >>> mammoth = Mammoth()
+
+You can create a context object and as a layout for it:
+
+  >>> mammoth = Mammoth('arthur')
   >>> mylayout = getMultiAdapter((request, mammoth), ILayout)
-  >>> ILayout.providedBy(mylayout)
+  >>> mylayout
+  <five.megrok.layout.ftests.layout.layout.MyLayout object at ...>
+  >>> verifyObject(ILayout, mylayout)
   True
-
-  >>> mylayout.context
-  <five.megrok.layout.ftests.layout.layout.Mammoth object at ...>
-
+  >>> mylayout.context.aq_base
+  <Mammoth at arthur>
   >>> mylayout.render()
   '<div> MyLayout </div>'
 
-  >>> elephant = Elephant()
+The layout can be different depending of the context:
+
+  >>> elephant = Elephant('paul')
   >>> mycontextlayout = getMultiAdapter((request, elephant), ILayout)
+  >>> mycontextlayout
+  <five.megrok.layout.ftests.layout.layout.MyContextLayout object at ...>
+  >>> mycontextlayout.context.aq_base
+  <Elephant at paul>
   >>> mycontextlayout.render()
   '<div> MyContextLayout </div>'
+
 """
 
 from five import grok
@@ -28,11 +39,11 @@ from zope import interface
 from five.megrok.layout import Layout
 
 
-class Mammoth(grok.Context):
+class Mammoth(grok.Model):
     pass
 
 
-class Elephant(grok.Context):
+class Elephant(grok.Model):
     pass
 
 
@@ -40,12 +51,12 @@ class MyLayout(Layout):
     grok.context(interface.Interface)
 
     def render(self):
-	return "<div> MyLayout </div>"
+        return "<div> MyLayout </div>"
 
 
 class MyContextLayout(Layout):
     grok.context(Elephant)
 
     def render(self):
-	return "<div> MyContextLayout </div>"
+        return "<div> MyContextLayout </div>"
 
